@@ -61,7 +61,8 @@ class Diff2HTMLTransform(Transform):
     def diff_line(self, trdata, w, line):
         cssclass = {'-': 'diffOldLine',
                     '+': 'diffNewLine',
-                    ' ': 'diffLine'}[line[0]]
+                    ' ': 'diffLine',
+                    '\\': 'diffOldLine'}[line[0]]
         if line.strip():
             w(u'<span class="%s">%s</span>\n' % (cssclass, xml_escape(line)))
 
