@@ -122,6 +122,10 @@ class SearchPatchStateInstructionOp(hook.DataOperationMixIn,
                     fire(readycandidates.pop(words[0]),
                          'ask review', u'review asked by %s in %s' % (
                              rev.author, rev.changeset or rev.revision))
+                elif words[0] == 'refuse' and words[1] in pendingcandidates:
+                    patch = pendingcandidates.pop(words[1])
+                    fire(patch, 'refuse', u'refused by %s in %s' % (
+                        rev.author, rev.changeset or rev.revision))
                 elif words[0] == 'reject' and words[1] in rejectcandidates:
                     patch = rejectcandidates.pop(words[1])
                     fire(patch, 'reject', u'rejected by %s in %s' % (
@@ -132,8 +136,8 @@ class SearchPatchStateInstructionOp(hook.DataOperationMixIn,
                     fire(patch, 'fold', u'folded by %s in %s' % (
                         rev.author, rev.changeset or rev.revision))
                     self.ensure_wont_be_deleted(patch)
-                elif words[0] == 'applied' and words[1] in pendingcandidates:
-                    patch = pendingcandidates.pop(words[1])
+                elif words[0] == 'applied' and words[1] in rejectcandidates:
+                    patch = rejectcandidates.pop(words[1])
                     fire(patch, 'accept', u'accepted by %s' % rev.author)
                     self.ensure_wont_be_deleted(patch)
                     # XXX search source repository changeset id
