@@ -38,7 +38,10 @@ pwf.add_transition(_('fold'), (inprogress, pending, deleted), folded,
                    ('managers',),)
 pwf.add_transition(_('refuse'), pending, inprogress,
                    ('managers',))
+# internal transition, not available through the ui
+# XXX we've to put 'managers' group since transition without groups
+# nor condition are fireable by anyone...
 pwf.add_transition(_('file deleted'), (inprogress, pending), deleted,
-                   ()) # internal transition, not available through the ui
+                   ('managers',))
 pwf.add_transition(_('reopen'), deleted, inprogress,
                    ('managers',))
