@@ -1,7 +1,6 @@
 
-from cubicweb.selectors import is_instance, is_in_state, score_entity
-from cubicweb.sobjects.notification import (StatusChangeMixIn, NotificationView,
-                                            ContentAddedView)
+from cubicweb.selectors import is_instance, is_in_state
+from cubicweb.sobjects.notification import StatusChangeMixIn, NotificationView
 from cubes.task import hooks as task
 
 class PatchStatusChangeView(StatusChangeMixIn, NotificationView):
@@ -11,7 +10,7 @@ class PatchStatusChangeView(StatusChangeMixIn, NotificationView):
                                                     'rejected')
 
     def subject(self):
-        entity = self.cw_rset.get_entity(0,0)
+        entity = self.cw_rset.get_entity(0, 0)
         return self._cw._(u'[%(repo)s] patch %(patch)s is now in state "%(state)s"') % {
             'repo': entity.repository.dc_title(),
             'patch': entity.dc_title(),
@@ -45,7 +44,7 @@ class TaskAddedView(task.TaskAddedView):
     content_attr = 'description'
 
     def subject(self):
-        entity = self.cw_rset.get_entity(0,0)
+        entity = self.cw_rset.get_entity(0, 0)
         patch = entity.activity_of
         if not patch:
             return super(TaskAddedView, self).subject()
