@@ -28,6 +28,7 @@ from cubicweb.web.views import primary, ibreadcrumbs
 from cubes.vcsfile.views import primary as vcsfile
 
 _pvs = uicfg.primaryview_section
+_pvdc = uicfg.primaryview_display_ctrl
 _abaa = uicfg.actionbox_appearsin_addmenu
 _afs = uicfg.autoform_section
 
@@ -36,6 +37,7 @@ _afs = uicfg.autoform_section
 
 _pvs.tag_subject_of(('Patch', 'patch_repository', '*'), 'hidden') # in breadcrumbs
 _pvs.tag_subject_of(('Patch', 'patch_revision', '*'), 'hidden') # table in attributes
+_pvdc.tag_subject_of(('Patch', 'applied_at', '*'), {'vid': 'incontext'})
 
 class PatchPrimaryView(primary.PrimaryView):
     __select__ = primary.PrimaryView.__select__ & is_instance('Patch')
@@ -90,9 +92,9 @@ _pvs.tag_object_of(('*', 'patch_repository', 'Repository'), 'hidden')
 
 
 def repo_patches_rql(is_patch_repo):
-    rql = ('Any P,PO,PB,PS,COUNT(VC) GROUPBY P,PO,PB,PS WHERE P in_state PS, '
-           'P originator PO, P branch PB, P patch_revision VC, P patch_repository R'
-           )
+    rql = ('Any P,PO,PB,PS,COUNT(TR),COUNT(VC) GROUPBY P,PO,PB,PS WHERE '
+           'P originator PO, P branch PB, P in_state PS, TR wf_info_for P, '
+           'P patch_revision VC, P patch_repository R')
     if is_patch_repo:
         rql += ', R eid %(x)s'
     else:
@@ -113,7 +115,7 @@ class RepositoryPatchesTab(EntityView):
         self.w('<p>%s. <a href="%s">%s</a></p>' % (
             self._cw._('Table below only show active patches'),
             xml_escape(linkurl), self._cw._('Show all patches')))
-        rql += ', PS name IN ("in-progress", "pending-review")'
+        rql += ', PS name IN ("in-progress", "pending-review", "deleted")'
         rset = self._cw.execute(rql, {'x': entity.eid})
         self.wview('table', rset, 'noresult', paginate=True, displayfilter=True)
 
